@@ -95,8 +95,9 @@ describe 'watcher::api' do
         is_expected.to contain_watcher_config('watcher_clients_auth/password').with_value( params[:watcher_client_password] )
         is_expected.to contain_watcher_config('watcher_clients_auth/auth_url').with_value('http://localhost:5000/')
         is_expected.to contain_watcher_config('watcher_clients_auth/auth_uri').with_value('http://localhost:5000/')
-        is_expected.to contain_watcher_config('watcher_clients_auth/project_name').with_value('service')
+        is_expected.to contain_watcher_config('watcher_clients_auth/project_name').with_value('services')
         is_expected.to contain_watcher_config('watcher_clients_auth/project_domain_name').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_watcher_config('watcher_clients_auth/user_domain_name').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_watcher_config('watcher_clients_auth/insecure').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_watcher_config('watcher_clients_auth/auth_type').with_value('password')
         is_expected.to contain_watcher_config('watcher_clients_auth/cafile').with_value('<SERVICE DEFAULT>')
@@ -114,6 +115,7 @@ describe 'watcher::api' do
           :watcher_client_auth_url            => 'http://localhost:35358/',
           :watcher_client_project_name        => 'ProjectZero',
           :watcher_client_project_domain_name => 'WatcherDomain',
+          :watcher_client_user_domain_name    => 'WatcherUserDomain',
           :watcher_client_insecure            => 'true',
           :watcher_client_auth_type           => 'password',
           :watcher_client_cafile              => '/tmp/ca.crt',
@@ -128,6 +130,7 @@ describe 'watcher::api' do
         is_expected.to contain_watcher_config('watcher_clients_auth/auth_url').with_value('http://localhost:35358/')
         is_expected.to contain_watcher_config('watcher_clients_auth/project_name').with_value( params[:watcher_client_project_name] )
         is_expected.to contain_watcher_config('watcher_clients_auth/project_domain_name').with_value( params[:watcher_client_project_domain_name] )
+        is_expected.to contain_watcher_config('watcher_clients_auth/user_domain_name').with_value( params[:watcher_client_user_domain_name] )
         is_expected.to contain_watcher_config('watcher_clients_auth/insecure').with_value( params[:watcher_client_insecure] )
         is_expected.to contain_watcher_config('watcher_clients_auth/auth_type').with_value( params[:watcher_client_auth_type] )
         is_expected.to contain_watcher_config('watcher_clients_auth/cafile').with_value( params[:watcher_client_cafile] )
